@@ -3,13 +3,23 @@ import os
 
 __ROOT__ = os.path.dirname(os.path.abspath(__file__))
 
-from .encoder import BertEncoder, LongTextEncoder, LongformerEncoder
+from .encoder import Encoder, LongTextEncoder, LongformerEncoder
+from .ner.n2g import Name2Gender, Gender
+from .ner import BertNER, NamedEntity, NamedPerson
 from .nn import (
+    FeedForward,
+    MultiHeadFeedForward,
     LinearRegression,
     LogisticRegression,
     SoftmaxRegression,
     RecursiveSequential,
-    AutoRegression
+    LongContextRecursiveSequential,
+    RoPE,
+    Attention,
+    MultiHeadAttention,
+    RoFormerEncoder,
+    AutoRegression,
+    LongContextAutoRegression
 )
 from .trainer import TextBinaryClassifierTrainer
 
@@ -32,3 +42,5 @@ logger = logging.getLogger('deeplotx.trainer')
 logger.setLevel(logging.DEBUG)
 logger = logging.getLogger('deeplotx.embedding')
 logger.setLevel(logging.DEBUG)
+logger = logging.getLogger('deeplotx.ner')
+logger.setLevel(logging.DEBUG)
