@@ -1,3 +1,3 @@
-from .bert_encoder import BertEncoder
+from .encoder import Encoder
 from .long_text_encoder import LongTextEncoder
 from .longformer_encoder import LongformerEncoder
